@@ -1,8 +1,7 @@
 import html
 import json
 import warnings
-from datetime import timedelta
-from urllib.parse import urlparse
+from urllib.parse import quote, urlparse
 
 from django import forms
 from django.conf import settings
@@ -356,7 +355,7 @@ class DefaultAccountAdapter(object):
         min_length = app_settings.PASSWORD_MIN_LENGTH
         if min_length and len(password) < min_length:
             raise forms.ValidationError(
-                self.error_message["password_min_length"].format(min_length)
+                self.error_messages["password_min_length"].format(min_length)
             )
         validate_password(password, user)
         return password
@@ -530,6 +529,7 @@ class DefaultAccountAdapter(object):
         Marks the email address as confirmed on the db
         """
         from allauth.account.models import EmailAddress
+        from allauth.account.utils import emit_email_changed
 
         from_email_address = (
             EmailAddress.objects.filter(user_id=email_address.user_id)
@@ -545,13 +545,7 @@ class DefaultAccountAdapter(object):
                 user_id=email_address.user_id
             ).exclude(pk=email_address.pk):
                 instance.remove()
-            signals.email_changed.send(
-                sender=get_user_model(),
-                request=request,
-                user=email_address.user,
-                from_email_address=from_email_address,
-                to_email_address=email_address,
-            )
+            emit_email_changed(request, from_email_address, email_address)
         return True
 
     def set_password(self, user, password):
@@ -588,6 +582,20 @@ class DefaultAccountAdapter(object):
 
         return url_has_allowed_host_and_scheme(url, allowed_hosts=allowed_hosts)
 
+    def get_reset_password_from_key_url(self, key):
+        """
+        Method intented to be overriden in case the password reset email
+        needs to point to your frontend/SPA.
+        """
+        # We intentionally accept an opaque `key` on the interface here, and not
+        # implementation details such as a separate `uidb36` and `key. Ideally,
+        # this should have done on `urls` level as well.
+        path = reverse(
+            "account_reset_password_from_key", kwargs={"uidb36": "UID", "key": "KEY"}
+        )
+        path = path.replace("UID-KEY", quote(key))
+        return build_absolute_uri(self.request, path)
+
     def get_email_confirmation_url(self, request, emailconfirmation):
         """Constructs the email confirmation (activation) url.
 
@@ -600,22 +608,11 @@ class DefaultAccountAdapter(object):
         return ret
 
     def should_send_confirmation_mail(self, request, email_address, signup):
-        from allauth.account.models import EmailConfirmation
-
-        cooldown_period = timedelta(seconds=app_settings.EMAIL_CONFIRMATION_COOLDOWN)
-        if app_settings.EMAIL_CONFIRMATION_HMAC:
-            send_email = ratelimit.consume(
-                request,
-                action="confirm_email",
-                key=email_address.email.lower(),
-                amount=1,
-                duration=cooldown_period.total_seconds(),
-            )
-        else:
-            send_email = not EmailConfirmation.objects.filter(
-                sent__gt=timezone.now() - cooldown_period,
-                email_address=email_address,
-            ).exists()
+        send_email = ratelimit.consume(
+            request,
+            action="confirm_email",
+            key=email_address.email.lower(),
+        )
         return send_email
 
     def send_account_already_exists_mail(self, email):
@@ -655,23 +652,17 @@ class DefaultAccountAdapter(object):
         return "{site}:{login}".format(site=site.domain, login=login)
 
     def _delete_login_attempts_cached_email(self, request, **credentials):
-        if app_settings.LOGIN_ATTEMPTS_LIMIT:
-            cache_key = self._get_login_attempts_cache_key(request, **credentials)
-            ratelimit.clear(request, action="login_failed", key=cache_key)
+        cache_key = self._get_login_attempts_cache_key(request, **credentials)
+        ratelimit.clear(request, action="login_failed", key=cache_key)
 
     def pre_authenticate(self, request, **credentials):
-        if app_settings.LOGIN_ATTEMPTS_LIMIT:
-            cache_key = self._get_login_attempts_cache_key(request, **credentials)
-            if not ratelimit.consume(
-                request,
-                action="login_failed",
-                key=cache_key,
-                amount=app_settings.LOGIN_ATTEMPTS_LIMIT,
-                duration=app_settings.LOGIN_ATTEMPTS_TIMEOUT,
-            ):
-                raise forms.ValidationError(
-                    self.error_messages["too_many_login_attempts"]
-                )
+        cache_key = self._get_login_attempts_cache_key(request, **credentials)
+        if not ratelimit.consume(
+            request,
+            action="login_failed",
+            key=cache_key,
+        ):
+            raise forms.ValidationError(self.error_messages["too_many_login_attempts"])
 
     def authenticate(self, request, **credentials):
         """Only authenticates, does not actually login. See `login`"""
@@ -682,7 +673,7 @@ class DefaultAccountAdapter(object):
         user = authenticate(request, **credentials)
         alt_user = AuthenticationBackend.unstash_authenticated_user()
         user = user or alt_user
-        if user and app_settings.LOGIN_ATTEMPTS_LIMIT:
+        if user:
             self._delete_login_attempts_cached_email(request, **credentials)
         else:
             self.authentication_failed(request, **credentials)
@@ -722,6 +713,9 @@ class DefaultAccountAdapter(object):
             ip = request.META.get("REMOTE_ADDR")
         return ip
 
+    def get_http_user_agent(self, request):
+        return request.META.get("HTTP_USER_AGENT", "Unspecified")
+
     def generate_emailconfirmation_key(self, email):
         key = get_random_string(64).lower()
         return key
@@ -758,6 +752,24 @@ class DefaultAccountAdapter(object):
                 )
         return ret
 
+    def send_notification_mail(self, template_prefix, user, context=None, email=None):
+        from allauth.account.models import EmailAddress
+
+        if not app_settings.EMAIL_NOTIFICATIONS:
+            return
+        if not email:
+            email = EmailAddress.objects.get_primary_email(user)
+        if not email:
+            return
+        ctx = {
+            "timestamp": timezone.now(),
+            "ip": self.get_client_ip(self.request),
+            "user_agent": self.get_http_user_agent(self.request),
+        }
+        if context:
+            ctx.update(context)
+        self.send_mail(template_prefix, email, ctx)
+
 
 def get_adapter(request=None):
     return import_attribute(app_settings.ADAPTER)(request)
