@@ -15,9 +15,8 @@ def AccountMiddleware(get_response):
             with context.request_context(request):
                 try:
                     response = await get_response(request)
-                    _remove_dangling_login(
-                        request, response, sync_to_async(_session_check)
-                    )
+                    if _should_check_dangling_login(request, response):
+                        await _acheck_dangling_login(request)
                     return response
                 except ImmediateHttpResponse as e:
                     return e.response
@@ -28,7 +27,8 @@ def AccountMiddleware(get_response):
             with context.request_context(request):
                 try:
                     response = get_response(request)
-                    _remove_dangling_login(request, response, _session_check)
+                    if _should_check_dangling_login(request, response):
+                        _check_dangling_login(request)
                     return response
                 except ImmediateHttpResponse as e:
                     return e.response
@@ -36,24 +36,28 @@ def AccountMiddleware(get_response):
     return middleware
 
 
-def _remove_dangling_login(request, response, session_check):
+def _should_check_dangling_login(request, response):
     content_type = response.headers.get("content-type")
     if content_type:
         content_type = content_type.partition(";")[0]
     if content_type and content_type != "text/html":
-        return
+        return False
     if request.path.startswith(settings.STATIC_URL) or request.path in [
         "/favicon.ico",
         "/robots.txt",
         "/humans.txt",
     ]:
-        return
+        return False
     if response.status_code // 100 != 2:
-        return
-    session_check(request)
+        return False
+    return True
 
 
-def _session_check(request):
+def _check_dangling_login(request):
     if not getattr(request, "_account_login_accessed", False):
         if "account_login" in request.session:
             request.session.pop("account_login")
+
+
+async def _acheck_dangling_login(request):
+    await sync_to_async(_check_dangling_login)(request)
