@@ -7,6 +7,7 @@ from django.core.validators import validate_email
 from django.forms import ValidationError
 from django.http import (
     Http404,
+    HttpResponse,
     HttpResponsePermanentRedirect,
     HttpResponseRedirect,
 )
@@ -43,6 +44,7 @@ from allauth.account.reauthentication import (
 )
 from allauth.account.utils import (
     complete_signup,
+    emit_email_changed,
     get_login_redirect_url,
     get_next_redirect_url,
     logout_on_password_change,
@@ -51,6 +53,7 @@ from allauth.account.utils import (
     send_email_confirmation,
     sync_user_email_addresses,
     url_str_to_user_pk,
+    user_display,
 )
 from allauth.core import ratelimit
 from allauth.core.exceptions import ImmediateHttpResponse
@@ -332,7 +335,12 @@ class ConfirmEmailView(TemplateResponseMixin, LogoutFunctionalityMixin, View):
         except Http404:
             self.object = None
         ctx = self.get_context_data()
-        return self.render_to_response(ctx)
+        if not self.object and get_adapter().is_ajax(self.request):
+            resp = HttpResponse()
+            resp.status_code = 400
+        else:
+            resp = self.render_to_response(ctx)
+        return _ajax_response(self.request, resp, data=self.get_ajax_data())
 
     def logout_other_user(self, confirmation):
         """
@@ -442,6 +450,15 @@ class ConfirmEmailView(TemplateResponseMixin, LogoutFunctionalityMixin, View):
         qs = qs.select_related("email_address__user")
         return qs
 
+    def get_ajax_data(self):
+        ret = {
+            "can_confirm": bool(self.object),
+        }
+        if self.object:
+            ret["email"] = self.object.email_address.email
+            ret["user"] = {"display": user_display(self.object.email_address.user)}
+        return ret
+
     def get_context_data(self, **kwargs):
         ctx = kwargs
         site = get_current_site(self.request)
@@ -466,6 +483,7 @@ class ConfirmEmailView(TemplateResponseMixin, LogoutFunctionalityMixin, View):
 confirm_email = ConfirmEmailView.as_view()
 
 
+@method_decorator(login_required, name="dispatch")
 @method_decorator(rate_limit(action="manage_email"), name="dispatch")
 @method_decorator(
     reauthentication_required(
@@ -494,7 +512,8 @@ class EmailView(AjaxCapableProcessFormViewMixin, FormView):
 
     def form_valid(self, form):
         email_address = form.save(self.request)
-        get_adapter(self.request).add_message(
+        adapter = get_adapter(self.request)
+        adapter.add_message(
             self.request,
             messages.INFO,
             "account/messages/email_confirmation_sent.txt",
@@ -572,6 +591,11 @@ class EmailView(AjaxCapableProcessFormViewMixin, FormView):
                     "account/messages/email_deleted.txt",
                     {"email": email_address.email},
                 )
+                adapter.send_notification_mail(
+                    "account/email/email_deleted",
+                    request.user,
+                    {"deleted_email": email_address.email},
+                )
                 return HttpResponseRedirect(self.get_success_url())
 
     def _action_primary(self, request, *args, **kwargs):
@@ -602,18 +626,13 @@ class EmailView(AjaxCapableProcessFormViewMixin, FormView):
                 except EmailAddress.DoesNotExist:
                     from_email_address = None
                 email_address.set_as_primary()
-                get_adapter().add_message(
+                adapter = get_adapter()
+                adapter.add_message(
                     request,
                     messages.SUCCESS,
                     "account/messages/primary_email_set.txt",
                 )
-                signals.email_changed.send(
-                    sender=request.user.__class__,
-                    request=request,
-                    user=request.user,
-                    from_email_address=from_email_address,
-                    to_email_address=email_address,
-                )
+                emit_email_changed(request, from_email_address, email_address)
                 return HttpResponseRedirect(self.get_success_url())
 
     def get_context_data(self, **kwargs):
@@ -661,9 +680,10 @@ class EmailView(AjaxCapableProcessFormViewMixin, FormView):
         return data
 
 
-email = login_required(EmailView.as_view())
+email = EmailView.as_view()
 
 
+@method_decorator(login_required, name="dispatch")
 @method_decorator(rate_limit(action="change_password"), name="dispatch")
 class PasswordChangeView(AjaxCapableProcessFormViewMixin, FormView):
     template_name = "account/password_change." + app_settings.TEMPLATE_EXTENSION
@@ -691,11 +711,15 @@ class PasswordChangeView(AjaxCapableProcessFormViewMixin, FormView):
     def form_valid(self, form):
         form.save()
         logout_on_password_change(self.request, form.user)
-        get_adapter(self.request).add_message(
+        adapter = get_adapter(self.request)
+        adapter.add_message(
             self.request,
             messages.SUCCESS,
             "account/messages/password_changed.txt",
         )
+        adapter.send_notification_mail(
+            "account/email/password_changed", self.request.user
+        )
         signals.password_changed.send(
             sender=self.request.user.__class__,
             request=self.request,
@@ -711,9 +735,10 @@ class PasswordChangeView(AjaxCapableProcessFormViewMixin, FormView):
         return ret
 
 
-password_change = login_required(PasswordChangeView.as_view())
+password_change = PasswordChangeView.as_view()
 
 
+@method_decorator(login_required, name="dispatch")
 @method_decorator(
     # NOTE: 'change_password' (iso 'set_') is intentional, there is no need to
     # differentiate between set and change.
@@ -745,15 +770,18 @@ class PasswordSetView(AjaxCapableProcessFormViewMixin, FormView):
 
     def form_valid(self, form):
         form.save()
-        logout_on_password_change(self.request, form.user)
-        get_adapter(self.request).add_message(
+        user = form.user
+        logout_on_password_change(self.request, user)
+        adapter = get_adapter(self.request)
+        adapter.add_message(
             self.request, messages.SUCCESS, "account/messages/password_set.txt"
         )
         signals.password_set.send(
-            sender=self.request.user.__class__,
+            sender=user.__class__,
             request=self.request,
-            user=self.request.user,
+            user=user,
         )
+        adapter.send_notification_mail("account/email/password_set", user)
         return super().form_valid(form)
 
     def get_context_data(self, **kwargs):
@@ -764,10 +792,9 @@ class PasswordSetView(AjaxCapableProcessFormViewMixin, FormView):
         return ret
 
 
-password_set = login_required(PasswordSetView.as_view())
+password_set = PasswordSetView.as_view()
 
 
-@method_decorator(rate_limit(action="reset_password"), name="dispatch")
 class PasswordResetView(AjaxCapableProcessFormViewMixin, FormView):
     template_name = "account/password_reset." + app_settings.TEMPLATE_EXTENSION
     form_class = ResetPasswordForm
@@ -780,7 +807,7 @@ class PasswordResetView(AjaxCapableProcessFormViewMixin, FormView):
     def form_valid(self, form):
         r429 = ratelimit.consume_or_429(
             self.request,
-            action="reset_password_email",
+            action="reset_password",
             key=form.cleaned_data["email"].lower(),
         )
         if r429:
@@ -831,8 +858,10 @@ class PasswordResetFromKeyView(
         user_token_form_class = get_form_class(
             app_settings.FORMS, "user_token", UserTokenForm
         )
-        if self.key == self.reset_url_key:
-            self.key = self.request.session.get(INTERNAL_RESET_SESSION_KEY, "")
+        is_ajax = get_adapter().is_ajax(request)
+        if self.key == self.reset_url_key or is_ajax:
+            if not is_ajax:
+                self.key = self.request.session.get(INTERNAL_RESET_SESSION_KEY, "")
             # (Ab)using forms here to be able to handle errors in XHR #890
             token_form = user_token_form_class(data={"uidb36": uidb36, "key": self.key})
             if token_form.is_valid():
@@ -887,7 +916,7 @@ class PasswordResetFromKeyView(
         form.save()
         adapter = get_adapter(self.request)
 
-        if self.reset_user and app_settings.LOGIN_ATTEMPTS_LIMIT:
+        if self.reset_user:
             # User successfully reset the password, clear any
             # possible cache entries for all email addresses.
             for email in self.reset_user.emailaddress_set.all():
@@ -905,6 +934,7 @@ class PasswordResetFromKeyView(
             request=self.request,
             user=self.reset_user,
         )
+        adapter.send_notification_mail("account/email/password_reset", self.reset_user)
 
         if app_settings.LOGIN_ON_PASSWORD_RESET:
             return perform_login(
@@ -1055,6 +1085,7 @@ class BaseReauthenticateView(FormView):
         return alts
 
 
+@method_decorator(login_required, name="dispatch")
 class ReauthenticateView(BaseReauthenticateView):
     form_class = ReauthenticateForm
     template_name = "account/reauthenticate." + app_settings.TEMPLATE_EXTENSION
@@ -1068,4 +1099,4 @@ class ReauthenticateView(BaseReauthenticateView):
         return ret
 
 
-reauthenticate = login_required(ReauthenticateView.as_view())
+reauthenticate = ReauthenticateView.as_view()
