@@ -153,6 +153,7 @@ class ActivateTOTPView(FormView):
         adapter.add_message(
             self.request, messages.SUCCESS, "mfa/messages/totp_activated.txt"
         )
+        adapter.send_notification_mail("mfa/email/totp_activated", self.request.user)
         return super().form_valid(form)
 
 
@@ -212,6 +213,7 @@ class DeactivateTOTPView(FormView):
         adapter.add_message(
             self.request, messages.SUCCESS, "mfa/messages/totp_deactivated.txt"
         )
+        adapter.send_notification_mail("mfa/email/totp_deactivated", self.request.user)
         return super().form_valid(form)
 
 
@@ -236,6 +238,9 @@ class GenerateRecoveryCodesView(FormView):
         signals.authenticator_reset.send(
             sender=Authenticator, user=self.request.user, authenticator=rc_auth.instance
         )
+        adapter.send_notification_mail(
+            "mfa/email/recovery_codes_generated", self.request.user
+        )
         return super().form_valid(form)
 
     def get_context_data(self, **kwargs):
