@@ -143,6 +143,10 @@ class AppSettings(object):
     def REQUESTS_TIMEOUT(self):
         return self._setting("REQUESTS_TIMEOUT", 5)
 
+    @property
+    def OPENID_CONNECT_URL_PREFIX(self):
+        return self._setting("OPENID_CONNECT_URL_PREFIX", "oidc")
+
 
 _app_settings = AppSettings("SOCIALACCOUNT_")
 
