@@ -1,4 +1,3 @@
-import requests
 from datetime import datetime, timedelta
 from urllib.parse import parse_qsl, quote, urlencode
 
@@ -36,10 +35,11 @@ class AppleOAuth2Client(OAuth2Client):
     def generate_client_secret(self):
         """Create a JWT signed with an apple provided private key"""
         now = datetime.utcnow()
-        app = get_adapter().get_app(self.request, "apple")
+        app = get_adapter(self.request).get_app(self.request, "apple")
         if not app.key:
             raise ImproperlyConfigured("Apple 'key' missing")
-        if not app.certificate_key:
+        certificate_key = app.settings.get("certificate_key")
+        if not certificate_key:
             raise ImproperlyConfigured("Apple 'certificate_key' missing")
         claims = {
             "iss": app.key,
@@ -50,7 +50,7 @@ class AppleOAuth2Client(OAuth2Client):
         }
         headers = {"kid": self.consumer_secret, "alg": "ES256"}
         client_secret = jwt_encode(
-            payload=claims, key=app.certificate_key, algorithm="ES256", headers=headers
+            payload=claims, key=certificate_key, algorithm="ES256", headers=headers
         )
         return client_secret
 
@@ -71,8 +71,10 @@ class AppleOAuth2Client(OAuth2Client):
         if pkce_code_verifier:
             data["code_verifier"] = pkce_code_verifier
         self._strip_empty_keys(data)
-        resp = requests.request(
-            self.access_token_method, url, data=data, headers=self.headers
+        resp = (
+            get_adapter()
+            .get_requests_session()
+            .request(self.access_token_method, url, data=data, headers=self.headers)
         )
         access_token = None
         if resp.status_code in [200, 201]:
