@@ -1,5 +1,4 @@
-import requests
-
+from allauth.socialaccount.adapter import get_adapter
 from allauth.socialaccount.providers.oauth2.views import (
     OAuth2Adapter,
     OAuth2CallbackView,
@@ -16,7 +15,11 @@ class AsanaOAuth2Adapter(OAuth2Adapter):
     profile_url = "https://app.asana.com/api/1.0/users/me"
 
     def complete_login(self, request, app, token, **kwargs):
-        resp = requests.get(self.profile_url, params={"access_token": token.token})
+        resp = (
+            get_adapter()
+            .get_requests_session()
+            .get(self.profile_url, params={"access_token": token.token})
+        )
         extra_data = resp.json()["data"]
         return self.get_provider().sociallogin_from_response(request, extra_data)
 
