@@ -1,7 +1,6 @@
-import requests
-
 from django.conf import settings
 
+from allauth.socialaccount.adapter import get_adapter
 from allauth.socialaccount.providers.oauth2.views import (
     OAuth2Adapter,
     OAuth2CallbackView,
@@ -42,13 +41,16 @@ class DwollaOAuth2Adapter(OAuth2Adapter):
     authorize_url = AUTH_URL
 
     def complete_login(self, request, app, token, response, **kwargs):
-
-        resp = requests.get(
-            response["_links"]["account"]["href"],
-            headers={
-                "authorization": "Bearer %s" % token.token,
-                "accept": "application/vnd.dwolla.v1.hal+json",
-            },
+        resp = (
+            get_adapter()
+            .get_requests_session()
+            .get(
+                response["_links"]["account"]["href"],
+                headers={
+                    "authorization": "Bearer %s" % token.token,
+                    "accept": "application/vnd.dwolla.v1.hal+json",
+                },
+            )
         )
 
         extra_data = resp.json()
