@@ -1,6 +1,5 @@
-import requests
-
 from allauth.socialaccount import app_settings
+from allauth.socialaccount.adapter import get_adapter
 from allauth.socialaccount.providers.oauth2.views import (
     OAuth2Adapter,
     OAuth2CallbackView,
@@ -26,13 +25,21 @@ class EdxOAuth2Adapter(OAuth2Adapter):
 
     def complete_login(self, request, app, token, **kwargs):
         headers = {"Authorization": "Bearer {0}".format(token.token)}
-        response = requests.get(self.profile_url, headers=headers)
+        response = (
+            get_adapter().get_requests_session().get(self.profile_url, headers=headers)
+        )
         extra_data = response.json()
 
         if extra_data.get("email", None) is None:
-            response = requests.get(
-                self.account_url.format(self.provider_base_url, extra_data["username"]),
-                headers=headers,
+            response = (
+                get_adapter()
+                .get_requests_session()
+                .get(
+                    self.account_url.format(
+                        self.provider_base_url, extra_data["username"]
+                    ),
+                    headers=headers,
+                )
             )
             extra_data = response.json()
 
