@@ -5,15 +5,12 @@ from django.core.exceptions import PermissionDenied
 from django.views.decorators.csrf import csrf_exempt
 from django.views.generic import View
 
-import jwt
-from cryptography.hazmat.backends import default_backend
-from cryptography.x509 import load_pem_x509_certificate
-
 from allauth.socialaccount.adapter import get_adapter
 from allauth.socialaccount.helpers import (
     complete_social_login,
     render_authentication_error,
 )
+from allauth.socialaccount.internal import jwtkit
 from allauth.socialaccount.providers.oauth2.client import OAuth2Error
 from allauth.socialaccount.providers.oauth2.views import (
     OAuth2Adapter,
@@ -61,6 +58,17 @@ FETCH_USERINFO = (
 )
 
 
+def _verify_and_decode(app, credential, verify_signature=True):
+    return jwtkit.verify_and_decode(
+        credential=credential,
+        keys_url=CERTS_URL,
+        issuer=ID_TOKEN_ISSUER,
+        audience=app.client_id,
+        lookup_kid=jwtkit.lookup_kid_pem_x509_certificate,
+        verify_signature=verify_signature,
+    )
+
+
 class GoogleOAuth2Adapter(OAuth2Adapter):
     provider_id = GoogleProvider.id
     access_token_url = ACCESS_TOKEN_URL
@@ -85,27 +93,15 @@ class GoogleOAuth2Adapter(OAuth2Adapter):
         return login
 
     def _decode_id_token(self, app, id_token):
-        try:
-            data = jwt.decode(
-                id_token,
-                # Since the token was received by direct communication
-                # protected by TLS between this library and Google, we
-                # are allowed to skip checking the token signature
-                # according to the OpenID Connect Core 1.0
-                # specification.
-                # https://openid.net/specs/openid-connect-core-1_0.html#IDTokenValidation
-                options={
-                    "verify_signature": False,
-                    "verify_iss": True,
-                    "verify_aud": True,
-                    "verify_exp": True,
-                },
-                issuer=self.id_token_issuer,
-                audience=app.client_id,
-            )
-        except jwt.PyJWTError as e:
-            raise OAuth2Error("Invalid id_token") from e
-        return data
+        """
+        If the token was received by direct communication protected by
+        TLS between this library and Google, we are allowed to skip checking the
+        token signature according to the OpenID Connect Core 1.0 specification.
+
+        https://openid.net/specs/openid-connect-core-1_0.html#IDTokenValidation
+        """
+        verify_signature = not self.did_fetch_access_token
+        return _verify_and_decode(app, id_token, verify_signature=verify_signature)
 
     def _fetch_user_info(self, access_token):
         resp = (
@@ -132,9 +128,9 @@ class LoginByTokenView(View):
         try:
             return super().dispatch(request)
         except (
+            OAuth2Error,
             requests.RequestException,
             PermissionDenied,
-            jwt.PyJWTError,
         ) as exc:
             return render_authentication_error(request, self.provider, exception=exc)
 
@@ -147,20 +143,7 @@ class LoginByTokenView(View):
         self.check_csrf(request)
 
         credential = request.POST.get("credential")
-        alg, key = self.get_key(credential)
-        identity_data = jwt.decode(
-            credential,
-            key,
-            options={
-                "verify_signature": True,
-                "verify_iss": True,
-                "verify_aud": True,
-                "verify_exp": True,
-            },
-            issuer=ID_TOKEN_ISSUER,
-            audience=self.provider.app.client_id,
-            algorithms=[alg],
-        )
+        identity_data = _verify_and_decode(app=self.provider.app, credential=credential)
         login = self.provider.sociallogin_from_response(request, identity_data)
         return complete_social_login(request, login)
 
@@ -174,21 +157,5 @@ class LoginByTokenView(View):
         if csrf_token_cookie != csrf_token_body:
             raise PermissionDenied("Failed to verify double submit cookie.")
 
-    def get_key(self, credential):
-        header = jwt.get_unverified_header(credential)
-        # {'alg': 'RS256', 'kid': '0ad1fec78504f447bae65bcf5afaedb65eec9e81', 'typ': 'JWT'}
-        kid = header["kid"]
-        alg = header["alg"]
-        response = get_adapter().get_requests_session().get(CERTS_URL)
-        response.raise_for_status()
-        jwks = response.json()
-        key = jwks.get(kid)
-        if not key:
-            raise PermissionDenied("invalid 'kid'")
-        key = load_pem_x509_certificate(
-            key.encode("utf8"), default_backend()
-        ).public_key()
-        return alg, key
-
 
 login_by_token = csrf_exempt(LoginByTokenView.as_view())
