@@ -1,6 +1,5 @@
 """Views for MailChimp API v3."""
-import requests
-
+from allauth.socialaccount.adapter import get_adapter
 from allauth.socialaccount.providers.oauth2.views import (
     OAuth2Adapter,
     OAuth2CallbackView,
@@ -23,7 +22,9 @@ class MailChimpOAuth2Adapter(OAuth2Adapter):
     def complete_login(self, request, app, token, **kwargs):
         """Complete login, ensuring correct OAuth header."""
         headers = {"Authorization": "OAuth {0}".format(token.token)}
-        metadata = requests.get(self.profile_url, headers=headers)
+        metadata = (
+            get_adapter().get_requests_session().get(self.profile_url, headers=headers)
+        )
         extra_data = metadata.json()
         return self.get_provider().sociallogin_from_response(request, extra_data)
 
