@@ -30,9 +30,8 @@ class TrelloProvider(OAuthProvider):
 
     def get_auth_params(self, request, action):
         data = super(TrelloProvider, self).get_auth_params(request, action)
-        app = self.get_app(request)
         data["type"] = "web_server"
-        data["name"] = app.name
+        data["name"] = self.app.name
         data["scope"] = self.get_scope(request)
         # define here for how long it will be, this can be configured on the
         # social app
