@@ -1,5 +1,4 @@
-import requests
-
+from allauth.socialaccount.adapter import get_adapter
 from allauth.socialaccount.providers.oauth2.views import (
     OAuth2Adapter,
     OAuth2CallbackView,
@@ -16,9 +15,13 @@ class YNABOAuth2Adapter(OAuth2Adapter):
     profile_url = "https://api.youneedabudget.com/v1/user"
 
     def complete_login(self, request, app, token, **kwargs):
-        resp = requests.get(
-            self.profile_url,
-            headers={"Authorization": "Bearer {}".format(token.token)},
+        resp = (
+            get_adapter()
+            .get_requests_session()
+            .get(
+                self.profile_url,
+                headers={"Authorization": "Bearer {}".format(token.token)},
+            )
         )
         resp.raise_for_status()
         extra_data = resp.json()
