@@ -3,9 +3,12 @@ from django.contrib.auth.decorators import login_required
 from django.contrib.sites.shortcuts import get_current_site
 from django.http import HttpResponseRedirect
 from django.urls import reverse, reverse_lazy
+from django.utils.decorators import method_decorator
 from django.views.generic.base import TemplateView
 from django.views.generic.edit import FormView
 
+from allauth.account.decorators import reauthentication_required
+
 from ..account import app_settings as account_settings
 from ..account.adapter import get_adapter as get_account_adapter
 from ..account.views import (
@@ -53,8 +56,10 @@ class SignupView(
 
     def form_valid(self, form):
         self.request.session.pop("socialaccount_sociallogin", None)
-        form.save(self.request)
-        return helpers.complete_social_signup(self.request, self.sociallogin)
+        user, resp = form.try_save(self.request)
+        if not resp:
+            resp = helpers.complete_social_signup(self.request, self.sociallogin)
+        return resp
 
     def get_context_data(self, **kwargs):
         ret = super(SignupView, self).get_context_data(**kwargs)
@@ -91,6 +96,13 @@ class LoginErrorView(TemplateView):
 login_error = LoginErrorView.as_view()
 
 
+@method_decorator(
+    reauthentication_required(
+        allow_get=True,
+        enabled=lambda request: account_settings.REAUTHENTICATION_REQUIRED,
+    ),
+    name="dispatch",
+)
 class ConnectionsView(AjaxCapableProcessFormViewMixin, FormView):
     template_name = "socialaccount/connections." + account_settings.TEMPLATE_EXTENSION
     form_class = DisconnectForm
